@@ -1183,7 +1183,7 @@ void on_session_add_clicked(GtkButton *button, gpointer user_data) {
 		newses = (gchar*) gtk_entry_get_text((GtkEntry*) gtk_builder_get_object(builder, "entry_session_name"));
 		is_set = get_checkbox("checkbutton_isset");
 
-		if (strcmp(CONFIG_GROUP, newses) == 0 || strcmp("", newses) == 0) {
+		if (strcmp(CONFIG_GROUP, newses) == 0 || strcmp("", newses) == 0 || strchr(newses, '/') != NULL) {
 #ifndef MAEMO
 			confirm = gtk_message_dialog_new((GtkWindow*) main_window, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR,
 				GTK_BUTTONS_CANCEL, _("This session name is reserved, you cannot call it like this"));
@@ -1307,6 +1307,7 @@ void on_button_about_clicked(GtkButton *button, gpointer user_data) {
 		_("Catalan translation by Josep Sànchez <josep.sanchez@ubuntu.cat>"),
 		_("Brazilian Portuguese translation by Fábio Nogueira <deb-user-ba@ubuntu.com>"),
 		_("Indonesian translation by Waluyo Adi Siswanto <was.uthm@gmail.com>"),
+		_("Croatian translation by Bojan Vondra <bojanvondra@hotmail.com>"),
 		NULL
 	};
 
